import { ParticleDevice } from './ParticleCloud';
export interface SwitchConfig {
    names: string[];
    codes: string[];
    timestamp: number;
}
export declare type SwitchConfigChangedHandler = (timestamp: number) => void;
export declare type SwitchStateChangedHandler = (index: number, state: boolean) => void;
export declare class CloudSwitch {
    readonly particleDevice: ParticleDevice;
    private configChangedEventStream;
    private stateChangedEventStream;
    static createCloudSwitchForId(deviceId: string, accessToken: string): Promise<CloudSwitch>;
    static createCloudSwitchWithName(name: string, accessToken: string): Promise<CloudSwitch>;
    static createCloudSwitch(accessToken: string): Promise<CloudSwitch>;
    constructor(particleDevice: ParticleDevice);
    name(): string;
    id(): string;
    isOnline(): boolean;
    onSwitchConfigChanged(handler: SwitchConfigChangedHandler | undefined): Promise<void>;
    onSwitchStateChanged(handler: SwitchStateChangedHandler | undefined): Promise<void>;
    setSwitchConfig(switchConfig: SwitchConfig): Promise<number>;
    getSwitchConfig(): Promise<SwitchConfig>;
    switchStates(): Promise<boolean[]>;
    private switchStateFromResult;
    toggleSwitch(switchIndex: number): Promise<boolean>;
    turnOnSwitch(switchIndex: number): Promise<boolean>;
    turnOffSwitch(switchIndex: number): Promise<boolean>;
    getSwitchState(switchIndex: number): Promise<boolean>;
    setSwitchState(switchIndex: number, isOn: boolean): Promise<boolean>;
}
