declare type VariableType = string | number | boolean;
export interface ParticleError extends Error {
    statusCode: number;
    errorDescription: string;
    shortErrorDescription: string;
}
export interface ParticleDevice {
    id: string;
    name: string;
    online: boolean;
    last_heard: Date;
    functions: string[];
    variables: {
        [key: string]: string;
    };
    toString: () => string;
    callFunction: (name: string, argument: string) => Promise<number>;
    getVariable: <T extends VariableType>(name: string) => Promise<T>;
    getEventStream: (name: string) => Promise<ParticleEventStream>;
}
export interface ParticlEvent {
    name: string;
    data: string;
    ttl: number;
    published_at: Date;
    coreid: string;
}
export interface ParticleEventStream {
    abort: () => void;
    onEvent: (handler: (event: ParticlEvent) => void) => this;
    onError: (handler: (error: Error) => void) => this;
    onDisconnect: (handler: () => void) => this;
    onReconnect: (handler: () => void) => this;
    onReconnectSuccess: (handler: () => void) => this;
    onReconnectError: (handler: (error: Error) => void) => this;
}
export declare class ParticleCloud {
    private readonly accessToken;
    constructor(aceessToken: string);
    listDevices(): Promise<ParticleDevice[]>;
    getDevice(deviceId: string): Promise<ParticleDevice>;
    callFunction(deviceId: string, name: string, argument: string): Promise<number>;
    getVariable<T extends VariableType>(deviceId: string, name: string): Promise<T>;
    getEventStream(deviceID: string | undefined, name: string | undefined): Promise<ParticleEventStream>;
}
export {};
